body {
  color: #222;
  font-family: 'Hiragino Mincho ProN', 'MS PMincho', serif;
}
h1, th {
  font-weight: bold;
  font-family: 'HiraMinProN-W6', 'MS PMincho', serif;
}
h1 {
  border-top: 2px solid #667777;
  padding-top: 4px;
  padding-bottom: 4px;
  background-color: #EEFFFF;
  width: 80%;
}
table, th, td {
  border: 1px solid #667777;
  border-collapse: collapse;
  border-spacing: 0px;
  padding: 3px;
  background-color: #FEFFFF;
}
td.state {
  background-color: #FFFFFF;
}
th {
  background-color: #BBCCCC;
}
span.kind02, span.wrn {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind03 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind04 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind05 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind06 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind07 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind08 {
  background-color: #FF2800;  color: #EEFFFF;  padding: 1px;
}
span.kind10, span.adv {
  background-color: #FAF500;  padding: 1px;
}
span.kind12 {
  background-color: #FAF500;  padding: 1px;
}
span.kind13 {
  background-color: #FAF500;  padding: 1px;
}
span.kind14 {
  background-color: #FAF500;  padding: 1px;
}
span.kind15 {
  background-color: #FAF500;  padding: 1px;
}
span.kind16 {
  background-color: #FAF500;  padding: 1px;
}
span.kind17 {
  background-color: #FAF500;  padding: 1px;
}
span.kind18 {
  background-color: #FAF500;  padding: 1px;
}
span.kind19 {
  background-color: #FAF500;  padding: 1px;
}
span.kind32, span.emg {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind33 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind34 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind35 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind36 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind37 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind38 {
  background-color: #C800FF;  padding: 1px;  font-weight: bold;  color: #FFF;
}
span.kind00, span.clear {
  background-color: #C8C8CB;  padding: 1px; color: #222;
}
